==> devspaces-dashboard-rhel8-container-3.15-6.tar.gz: pkgs.devel.redhat.com/containers/devspaces-dashboard/devspaces-dashboard/packages/dashboard-backend/src/devworkspaceClient/__mocks__/index.ts <==
/*
 * Copyright (c) 2018-2024 Red Hat, Inc.
 * This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 2.0
 * which is available at https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *   Red Hat, Inc. - initial API and implementation
 */

import {
  IDevWorkspaceApi,
  IDevWorkspacePreferencesApi,
  IDevWorkspaceTemplateApi,
  IDockerConfigApi,
  IEditorsApi,
  IEventApi,
  IGettingStartedSampleApi,
  IGitConfigApi,
  IKubeConfigApi,
  ILogsApi,
  IPersonalAccessTokenApi,
  IPodApi,
  IServerConfigApi,
  IShhKeysApi,
  IUserProfileApi,
} from '@/devworkspaceClient/types';

import { IDevWorkspaceClient } from '..';

export class DevWorkspaceClient implements IDevWorkspaceClient {
  get eventApi(): IEventApi {
    throw new Error('Method not implemented.');
  }
  get devworkspaceApi(): IDevWorkspaceApi {
    throw new Error('Method not implemented.');
  }
  get devWorkspaceTemplateApi(): IDevWorkspaceTemplateApi {
    throw new Error('Method not implemented.');
  }
  get dockerConfigApi(): IDockerConfigApi {
    throw new Error('Method not implemented.');
  }
  get serverConfigApi(): IServerConfigApi {
    throw new Error('Method not implemented.');
  }
  get kubeConfigApi(): IKubeConfigApi {
    throw new Error('Method not implemented.');
  }
  get userProfileApi(): IUserProfileApi {
    throw new Error('Method not implemented.');
  }
  get logsApi(): ILogsApi {
    throw new Error('Method not implemented.');
  }
  get personalAccessTokenApi(): IPersonalAccessTokenApi {
    throw new Error('Method not implemented.');
  }
  get podApi(): IPodApi {
    throw new Error('Method not implemented.');
  }
  get gettingStartedSampleApi(): IGettingStartedSampleApi {
    throw new Error('Method not implemented.');
  }
  get gitConfigApi(): IGitConfigApi {
    throw new Error('Method not implemented.');
  }
  get sshKeysApi(): IShhKeysApi {
    throw new Error('Method not implemented.');
  }
  get devWorkspacePreferencesApi(): IDevWorkspacePreferencesApi {
    throw new Error('Method not implemented.');
  }

  get editorsApi(): IEditorsApi {
    throw new Error('Method not implemented.');
  }
}

==> devspaces-dashboard-rhel8-container-3.16-27.tar.gz: pkgs.devel.redhat.com/containers/devspaces-dashboard/devspaces-dashboard/packages/dashboard-backend/src/devworkspaceClient/__mocks__/index.ts <==
/*
 * Copyright (c) 2018-2024 Red Hat, Inc.
 * This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 2.0
 * which is available at https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *   Red Hat, Inc. - initial API and implementation
 */

import {
  IAirGapSampleApi,
  IDevWorkspaceApi,
  IDevWorkspaceTemplateApi,
  IDockerConfigApi,
  IEditorsApi,
  IEventApi,
  IGettingStartedSampleApi,
  IGitConfigApi,
  IKubeConfigApi,
  ILogsApi,
  IPersonalAccessTokenApi,
  IPodApi,
  IServerConfigApi,
  IShhKeysApi,
  IUserProfileApi,
  IWorkspacePreferencesApi,
} from '@/devworkspaceClient/types';

import { IDevWorkspaceClient } from '..';

export class DevWorkspaceClient implements IDevWorkspaceClient {
  get eventApi(): IEventApi {
    throw new Error('Method not implemented.');
  }
  get devworkspaceApi(): IDevWorkspaceApi {
    throw new Error('Method not implemented.');
  }
  get devWorkspaceTemplateApi(): IDevWorkspaceTemplateApi {
    throw new Error('Method not implemented.');
  }
  get dockerConfigApi(): IDockerConfigApi {
    throw new Error('Method not implemented.');
  }
  get serverConfigApi(): IServerConfigApi {
    throw new Error('Method not implemented.');
  }
  get kubeConfigApi(): IKubeConfigApi {
    throw new Error('Method not implemented.');
  }
  get userProfileApi(): IUserProfileApi {
    throw new Error('Method not implemented.');
  }
  get logsApi(): ILogsApi {
    throw new Error('Method not implemented.');
  }
  get personalAccessTokenApi(): IPersonalAccessTokenApi {
    throw new Error('Method not implemented.');
  }
  get podApi(): IPodApi {
    throw new Error('Method not implemented.');
  }
  get gettingStartedSampleApi(): IGettingStartedSampleApi {
    throw new Error('Method not implemented.');
  }

  get airGapSampleApi(): IAirGapSampleApi {
    throw new Error('Method not implemented.');
  }

  get gitConfigApi(): IGitConfigApi {
    throw new Error('Method not implemented.');
  }
  get sshKeysApi(): IShhKeysApi {
    throw new Error('Method not implemented.');
  }
  get workspacePreferencesApi(): IWorkspacePreferencesApi {
    throw new Error('Method not implemented.');
  }

  get editorsApi(): IEditorsApi {
    throw new Error('Method not implemented.');
  }
}
